==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/entity/BaFdcq2Ls.java <==
package cn.gtmap.realestate.supervise.entity;


import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description QLT_FW_FDCQ_YZ  房地产权（独幢、层、套、间房屋）属性结构
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_fdcq2_ls"
)
public class BaFdcq2Ls implements Serializable {


    @XmlAttribute
    @Id
    @id
    private String id;


    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
    private String ywh;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    private String fdzl;

    @XmlAttribute
    @encrypt
    private String tdsyqr;

    @XmlAttribute
    @Nullable
    private String dytdmj;

    @XmlAttribute
    @Nullable
    private String fttdmj;

    @XmlAttribute
    private Date tdsyqssj;

    @XmlAttribute
    private Date tdsyjssj;

    @XmlAttribute
    @Nullable
    private String fdcjyjg;

    @XmlAttribute
    private String ghyt;

    @XmlAttribute
    @Nullable
    private String fwxz;

    @XmlAttribute
    @Nullable
    private String fwjg;

    @XmlAttribute
    private String szc;

    @XmlAttribute
    private String zcs;

    @XmlAttribute
    private float jzmj;

    @XmlAttribute
    private float zyjzmj;

    @XmlAttribute
    private float ftjzmj;

    @XmlAttribute
    @Nullable
    private String jgsj;

    @XmlAttribute
    @Nullable
    private String bdcqzh;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    @Nullable
    private String fj;

    @XmlAttribute
    private String qszt;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String ssywh;

    @XmlAttribute
    private String tdsyqx;

    @XmlAttribute
    private String jedw;

    @XmlAttribute
    private String ytmc;

    @XmlAttribute
    private String pzyt;

    @XmlAttribute
    private String sjyt;

    @XmlAttribute
    private String fwxzmc;

    @XmlAttribute
    private String yt;

    @XmlAttribute
    private String fytz;

    @sqlx
    private String sqlx;

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getTdsyqx() {
        return tdsyqx;
    }

    public void setTdsyqx(String tdsyqx) {
        this.tdsyqx = tdsyqx;
    }

    public String getJedw() {
        return jedw;
    }

    public void setJedw(String jedw) {
        this.jedw = jedw;
    }

    public String getYtmc() {
        return ytmc;
    }

    public void setYtmc(String ytmc) {
        this.ytmc = ytmc;
    }

    public String getPzyt() {
        return pzyt;
    }

    public void setPzyt(String pzyt) {
        this.pzyt = pzyt;
    }

    public String getSjyt() {
        return sjyt;
    }

    public void setSjyt(String sjyt) {
        this.sjyt = sjyt;
    }

    public String getFwxzmc() {
        return fwxzmc;
    }

    public void setFwxzmc(String fwxzmc) {
        this.fwxzmc = fwxzmc;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public String getFdzl() {
        return fdzl;
    }

    public String getTdsyqr() {
        return tdsyqr;
    }

    public String getDytdmj() {
        return dytdmj;
    }

    public String getFttdmj() {
        return fttdmj;
    }

    public Date getTdsyqssj() {
        return tdsyqssj;
    }

    public Date getTdsyjssj() {
        return tdsyjssj;
    }

    public String getFdcjyjg() {
        return fdcjyjg;
    }

    public String getGhyt() {
        return ghyt;
    }

    public String getFwxz() {
        return fwxz;
    }

    public String getFwjg() {
        return fwjg;
    }

    public String getSzc() {
        return szc;
    }


    public float getJzmj() {
        return jzmj;
    }

    public float getZyjzmj() {
        return zyjzmj;
    }

    public float getFtjzmj() {
        return ftjzmj;
    }

    public String getJgsj() {
        return jgsj;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public String getFj() {
        return fj;
    }

    public String getQszt() {
        return qszt;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public void setFdzl(String fdzl) {
        this.fdzl = fdzl;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public void setDytdmj(String dytdmj) {
        this.dytdmj = dytdmj;
    }

    public void setFttdmj(String fttdmj) {
        this.fttdmj = fttdmj;
    }

    public void setTdsyqssj(Date tdsyqssj) {
        this.tdsyqssj = tdsyqssj;
    }

    public void setTdsyjssj(Date tdsyjssj) {
        this.tdsyjssj = tdsyjssj;
    }

    public void setFdcjyjg(String fdcjyjg) {
        this.fdcjyjg = fdcjyjg;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public String getZcs() {
        return zcs;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }

    public void setJzmj(float jzmj) {
        this.jzmj = jzmj;
    }

    public void setZyjzmj(float zyjzmj) {
        this.zyjzmj = zyjzmj;
    }

    public void setFtjzmj(float ftjzmj) {
        this.ftjzmj = ftjzmj;
    }

    public void setJgsj(String jgsj) {
        this.jgsj = jgsj;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getFytz() {
        return fytz;
    }

    public void setFytz(String fytz) {
        this.fytz = fytz;
    }
}

==> realestate-supervise-common-1.1.0-20251204.013828-71-sources.jar: cn/gtmap/realestate/supervise/entity/BaFdcq2Ls.java <==
package cn.gtmap.realestate.supervise.entity;


import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description QLT_FW_FDCQ_YZ  房地产权（独幢、层、套、间房屋）属性结构
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_fdcq2_ls"
)
public class BaFdcq2Ls implements Serializable {


    @XmlAttribute
    @Id
    @id
    private String id;


    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
    private String ywh;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    private String fdzl;

    @XmlAttribute
    @encrypt
    private String tdsyqr;

    @XmlAttribute
    @Nullable
    private String dytdmj;

    @XmlAttribute
    @Nullable
    private String fttdmj;

    @XmlAttribute
    private Date tdsyqssj;

    @XmlAttribute
    private Date tdsyjssj;

    @XmlAttribute
    @Nullable
    private String fdcjyjg;

    @XmlAttribute
    private String ghyt;

    @XmlAttribute
    @Nullable
    private String fwxz;

    @XmlAttribute
    @Nullable
    private String fwjg;

    @XmlAttribute
    private String szc;

    @XmlAttribute
    private String zcs;

    @XmlAttribute
    private float jzmj;

    @XmlAttribute
    private float zyjzmj;

    @XmlAttribute
    private float ftjzmj;

    @XmlAttribute
    @Nullable
    private String jgsj;

    @XmlAttribute
    @Nullable
    private String bdcqzh;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    @Nullable
    private String fj;

    @XmlAttribute
    private String qszt;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String ssywh;

    @XmlAttribute
    private String tdsyqx;

    @XmlAttribute
    private String jedw;

    @XmlAttribute
    private String ytmc;

    @XmlAttribute
    private String pzyt;

    @XmlAttribute
    private String sjyt;

    @XmlAttribute
    private String fwxzmc;

    @XmlAttribute
    private String yt;

    @XmlAttribute
    private String fytz;

    @sqlx
    private String sqlx;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段开始===============

    /** 原不动产单元号 */
    @XmlAttribute
    private String ybdcdyh;

    /** 用地用海分类代码 */
    @XmlAttribute
    private String ydyhfldm;

    /** 产权来源 */
    @XmlAttribute
    private String cqly;

    // ============73696 江苏省级_地籍数据监管模块总体需求新增字段结束===============

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getTdsyqx() {
        return tdsyqx;
    }

    public void setTdsyqx(String tdsyqx) {
        this.tdsyqx = tdsyqx;
    }

    public String getJedw() {
        return jedw;
    }

    public void setJedw(String jedw) {
        this.jedw = jedw;
    }

    public String getYtmc() {
        return ytmc;
    }

    public void setYtmc(String ytmc) {
        this.ytmc = ytmc;
    }

    public String getPzyt() {
        return pzyt;
    }

    public void setPzyt(String pzyt) {
        this.pzyt = pzyt;
    }

    public String getSjyt() {
        return sjyt;
    }

    public void setSjyt(String sjyt) {
        this.sjyt = sjyt;
    }

    public String getFwxzmc() {
        return fwxzmc;
    }

    public void setFwxzmc(String fwxzmc) {
        this.fwxzmc = fwxzmc;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public String getQllx() {
        return qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public String getFdzl() {
        return fdzl;
    }

    public String getTdsyqr() {
        return tdsyqr;
    }

    public String getDytdmj() {
        return dytdmj;
    }

    public String getFttdmj() {
        return fttdmj;
    }

    public Date getTdsyqssj() {
        return tdsyqssj;
    }

    public Date getTdsyjssj() {
        return tdsyjssj;
    }

    public String getFdcjyjg() {
        return fdcjyjg;
    }

    public String getGhyt() {
        return ghyt;
    }

    public String getFwxz() {
        return fwxz;
    }

    public String getFwjg() {
        return fwjg;
    }

    public String getSzc() {
        return szc;
    }


    public float getJzmj() {
        return jzmj;
    }

    public float getZyjzmj() {
        return zyjzmj;
    }

    public float getFtjzmj() {
        return ftjzmj;
    }

    public String getJgsj() {
        return jgsj;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public String getFj() {
        return fj;
    }

    public String getQszt() {
        return qszt;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public void setFdzl(String fdzl) {
        this.fdzl = fdzl;
    }

    public void setTdsyqr(String tdsyqr) {
        this.tdsyqr = tdsyqr;
    }

    public void setDytdmj(String dytdmj) {
        this.dytdmj = dytdmj;
    }

    public void setFttdmj(String fttdmj) {
        this.fttdmj = fttdmj;
    }

    public void setTdsyqssj(Date tdsyqssj) {
        this.tdsyqssj = tdsyqssj;
    }

    public void setTdsyjssj(Date tdsyjssj) {
        this.tdsyjssj = tdsyjssj;
    }

    public void setFdcjyjg(String fdcjyjg) {
        this.fdcjyjg = fdcjyjg;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public void setFwjg(String fwjg) {
        this.fwjg = fwjg;
    }

    public void setSzc(String szc) {
        this.szc = szc;
    }

    public String getZcs() {
        return zcs;
    }

    public void setZcs(String zcs) {
        this.zcs = zcs;
    }

    public void setJzmj(float jzmj) {
        this.jzmj = jzmj;
    }

    public void setZyjzmj(float zyjzmj) {
        this.zyjzmj = zyjzmj;
    }

    public void setFtjzmj(float ftjzmj) {
        this.ftjzmj = ftjzmj;
    }

    public void setJgsj(String jgsj) {
        this.jgsj = jgsj;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getFytz() {
        return fytz;
    }

    public void setFytz(String fytz) {
        this.fytz = fytz;
    }

    public String getYbdcdyh() {
        return ybdcdyh;
    }

    public void setYbdcdyh(String ybdcdyh) {
        this.ybdcdyh = ybdcdyh;
    }

    public String getYdyhfldm() {
        return ydyhfldm;
    }

    public void setYdyhfldm(String ydyhfldm) {
        this.ydyhfldm = ydyhfldm;
    }

    public String getCqly() {
        return cqly;
    }

    public void setCqly(String cqly) {
        this.cqly = cqly;
    }
}
